@@ -5,15 +5,15 @@ use warnings;
 
 use Getopt::Long;
 use Chart::GGPlot qw(:all);
-use Data::Frame::Examples qw(economics);
+use Data::Frame::Examples qw(economics_long);
 
 my $save_as;
 GetOptions( 'o=s' => \$save_as );
 
 my $p = ggplot(
-    data    => economics(),
-    mapping => aes( x => 'date', y => 'unemploy' )
-)->geom_line(color => 'red');
+    data    => economics_long(),
+    mapping => aes( x => 'date', y => 'value01', color => 'variable' )
+)->geom_line();
 
 if (defined $save_as) {
     $p->save($save_as);
