@@ -15,7 +15,7 @@ my $mtcars = mtcars();
 my $p = ggplot(
     data    => $mtcars,
     mapping => aes( x => 'wt', y => 'mpg' )
-)->geom_point(color => 'red', size => 3);
+)->geom_point( mapping => aes( size => 'qsec' ) );
 
 if (defined $save_as) {
     $p->save($save_as);
