@@ -7,19 +7,21 @@ use Getopt::Long;
 use Chart::GGPlot qw(:all);
 use Data::Frame;
 use PDL::Core qw(pdl);
+use PDL::Basic qw(sequence);
 use PDL::Primitive qw(random);
 
-srand(0);
-
 my $save_as;
 GetOptions( 'o=s' => \$save_as );
 
+my $n  = 201;
+my $x  = ( sequence($n) - $n / 2 )->repeat($n) * 0.1;
+my $y  = ( pdl( map { ($_) x $n } ( 0 .. $n - 1 ) ) - $n / 2 ) * 0.1;
+my $z  = ( $x**2 + $y**2 )->sqrt->sin;
 my $df = Data::Frame->new(
     columns => [
-        x => pdl( [ ( 0 .. 5 ) x 6 ] ),
-        y => pdl( [ map { ($_) x 6 } (0 .. 5) ] ),
-        # bottom-left should be the darkest, top-right the lightest
-        z => random(36)->qsort,
+        x => $x,
+        y => $y,
+        z => $z,
     ]
 );
 
@@ -28,9 +30,10 @@ my $p = ggplot(
     mapping => aes( x => 'x', y => 'y', fill => 'z' )
 )->geom_raster();
 
-if (defined $save_as) {
+if ( defined $save_as ) {
     $p->save($save_as);
-} else {
+}
+else {
     $p->show();
 }
 
