@@ -1,5 +1,7 @@
 #!/usr/bin/env perl
 
+# Change size of the label
+
 use 5.016;
 use warnings;
 
@@ -15,7 +17,7 @@ my $mtcars = mtcars();
 my $p = ggplot(
     data    => $mtcars,
     mapping => aes( x => 'wt', y => 'mpg', label => $mtcars->row_names )
-)->geom_text();
+)->geom_text( size => 10 );
 
 if ( defined $save_as ) {
     $p->save($save_as);
