@@ -5,15 +5,15 @@ use warnings;
 
 use Getopt::Long;
 use Chart::GGPlot qw(:all);
-use Data::Frame::Examples qw(diamonds);
+use Data::Frame::Examples qw(mtcars);
 
 my $save_as;
 GetOptions( 'o=s' => \$save_as );
 
 my $p = ggplot(
-    data    => diamonds(),
-    mapping => aes( x => 'price', fill => 'cut' )
-)->geom_histogram( position => 'dodge2' );
+    data    => mtcars(),
+    mapping => aes( x => 'factor($cyl)', fill => 'factor($vs)' )
+)->geom_bar( position => position_dodge2( preserve => 'single' ) );
 
 if ( defined $save_as ) {
     $p->save($save_as);
