@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 
-# Select brewer palette to use
+# the brewer scales look better on a darker background
 
 use 5.016;
 use warnings;
@@ -14,13 +14,12 @@ srand(0);
 my $save_as;
 GetOptions( 'o=s' => \$save_as );
 
-my $dsamp = diamonds()->sample(1000);
-
 my $p = ggplot(
-    data    => $dsamp,
-    mapping => aes( x => 'carat', y => 'price' )
-)->geom_point( mapping => aes( color => 'clarity' ) )
- ->scale_color_brewer( palette => 'Greens' );
+    data    => diamonds(),
+    mapping => aes( x => 'price', fill => 'cut' )
+)->geom_histogram( position => 'dodge', binwidth => 1000 )
+ ->scale_fill_brewer( direction => -1 )
+ ->theme_dark();
 
 if (defined $save_as) {
     $p->save($save_as);
