@@ -5,7 +5,6 @@ use warnings;
 
 use Getopt::Long;
 use Chart::GGPlot qw(:all);
-use Chart::GGPlot::Trans::Functions qw(reciprocal_trans);
 use Data::Frame::Examples qw(mpg);
 
 my $save_as;
@@ -17,7 +16,7 @@ my $p = ggplot(
     data    => $mpg,
     mapping => aes( x => 'displ', y => 'hwy' )
 )->geom_point()
- ->scale_y_continuous(trans => reciprocal_trans());
+ ->scale_y_sqrt();
 
 if ( defined $save_as ) {
     $p->save($save_as);
