@@ -18,7 +18,7 @@ my $p = ggplot(
     data    => $dsamp,
     mapping => aes( x => 'carat', y => 'price' )
 )->geom_point( mapping => aes( color => 'clarity' ) )
- ->scale_color_hue( h => [0, 90] );
+ ->scale_color_hue(l => 80, c => 150);
 
 if (defined $save_as) {
     $p->save($save_as);
