@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 
-# Change scale label
+# Select palette to use
 
 use 5.016;
 use warnings;
@@ -29,7 +29,7 @@ my $p = ggplot(
     data    => $txsamp,
     mapping => aes( x => 'sales', y => 'median' )
 )->geom_point( mapping => aes( color => 'city' ) )
- ->scale_color_viridis_d( name => "City Center" );
+ ->scale_color_viridis_d( option => "plasma" );
 
 if ( defined $save_as ) {
     $p->save($save_as);
